@@ -195,9 +195,9 @@
 
 
 # define VERSION	"2.4"				/* Version number... */
-# define VERS_DATE	"November 11, 1995"		/* for elm -v option */
+# define VERS_DATE	"October 1, 1992"		/* for elm -v option */
 # define WHAT_STRING	\
-	"@(#) Version 2.4, USENET supported version, released November 11, 1995"
+	"@(#) Version 2.4, USENET supported version, released October 1, 1992"
 
 #if defined(__STDC__) || defined(_AIX)
 # define ANSI_C 1
